@@ -1,8 +1,9 @@
-from typing import Dict, List, Optional
+from typing import Optional
 
 from robotoff import settings
-from robotoff.prediction.types import Prediction, PredictionType
+from robotoff.prediction.types import Prediction
 from robotoff.taxonomy import Taxonomy
+from robotoff.types import PredictionType
 from robotoff.utils import http_session
 
 
@@ -46,10 +47,10 @@ class CategoryClassifier:
 
     def predict(
         self,
-        product: Dict,
+        product: dict,
         deepest_only: bool = False,
         threshold: Optional[float] = None,
-    ) -> List[Prediction]:
+    ) -> list[Prediction]:
         """Returns an unordered list of category predictions for the given
         product.
 
@@ -84,7 +85,9 @@ class CategoryClassifier:
         }
 
         r = http_session.post(
-            f"{settings.TF_SERVING_BASE_URL}/category-classifier:predict", json=data
+            f"{settings.TF_SERVING_BASE_URL}/category-classifier:predict",
+            json=data,
+            timeout=(3.0, 10.0),
         )
         r.raise_for_status()
         response = r.json()
@@ -106,7 +109,7 @@ class CategoryClassifier:
         #
         # The model only returns top 50 predictions.
 
-        category_predictions: List[CategoryPrediction] = []
+        category_predictions: list[CategoryPrediction] = []
 
         # We only consider predictions with a confidence score of `threshold` and above.
         for idx, confidence in enumerate(prediction["output_mapper_layer"]):
