@@ -539,7 +539,7 @@ def visualize_boxes_and_labels_on_image_array(
     boxes,
     classes,
     scores,
-    category_index,
+    label_names,
     instance_masks=None,
     instance_boundaries=None,
     keypoints=None,
@@ -567,8 +567,7 @@ def visualize_boxes_and_labels_on_image_array(
       scores: a numpy array of shape [N] or None.  If scores=None, then
         this function assumes that the boxes to be plotted are groundtruth
         boxes and plot all boxes as black with no classes or scores.
-      category_index: a dict containing category dictionaries (each holding
-        category index `id` and category name `name`) keyed by category indices.
+      label_names: a list containing label names.
       instance_masks: a numpy array of shape [N, image_height, image_width] with
         values ranging between 0 and 1, can be None.
       instance_boundaries: a numpy array of shape [N, image_height, image_width]
@@ -616,8 +615,8 @@ def visualize_boxes_and_labels_on_image_array(
                 display_str = ""
                 if not skip_labels:
                     if not agnostic_mode:
-                        if classes[i] in category_index.keys():
-                            class_name = category_index[classes[i]]["name"]
+                        if len(label_names) > classes[i]:
+                            class_name = label_names[classes[i]]
                         else:
                             class_name = "N/A"
                         display_str = str(class_name)
