@@ -1,7 +1,7 @@
-from typing import Iterable, List, Optional, Union
+from typing import Iterable, Optional, Union
 
 from robotoff import settings
-from robotoff.prediction.types import Prediction, PredictionType
+from robotoff.prediction.types import Prediction
 from robotoff.products import ProductDataset
 from robotoff.spellcheck.base_spellchecker import BaseSpellchecker
 from robotoff.spellcheck.elasticsearch import ElasticSearchSpellchecker
@@ -9,6 +9,7 @@ from robotoff.spellcheck.items import SpellcheckItem
 from robotoff.spellcheck.patterns import PatternsSpellchecker
 from robotoff.spellcheck.percentages import PercentagesSpellchecker
 from robotoff.spellcheck.vocabulary import VocabularySpellchecker
+from robotoff.types import PredictionType
 from robotoff.utils.types import JSONType
 
 SPELLCHECKERS = {
@@ -20,17 +21,17 @@ SPELLCHECKERS = {
 
 
 class Spellchecker:
-    def __init__(self, pipeline: List[BaseSpellchecker]):
-        self.spellcheckers: List[BaseSpellchecker] = pipeline
+    def __init__(self, pipeline: list[BaseSpellchecker]):
+        self.spellcheckers: list[BaseSpellchecker] = pipeline
 
     @classmethod
     def load(
         cls,
         client,
-        pipeline: Optional[List[Union[str, BaseSpellchecker]]] = None,
+        pipeline: Optional[list[Union[str, BaseSpellchecker]]] = None,
         **es_kwargs,
     ):
-        pipeline_: List[BaseSpellchecker] = []
+        pipeline_: list[BaseSpellchecker] = []
 
         if pipeline is None:
             pipeline = ["patterns", "elasticsearch", "vocabulary"]
